@@ -18,8 +18,11 @@ class SynapseGroup(NetworkObjectBase):
         super().__init__(tag, net, behaviour)
         self.add_tag('syn')
 
-        if len(src.tags) > 0 and len(dst.tags) > 0:
-            self.add_tag(src.tags[0]+'_to_'+dst.tags[0])
+        if src is not None and dst is not None:
+            if len(src.tags) > 0 and len(dst.tags) > 0:
+                self.add_tag(src.tags[0]+'_to_'+dst.tags[0])
+        else:
+            print('Warning: Not able to find soource or taget for SynapseGroup '+self.tags)
 
         if net is not None:
             net.SynapseGroups.append(self)
